@@ -6,6 +6,69 @@ extends 'RapidApp::Module::NavTree';
 
 use RapidApp::Util qw(:all);
 
+# ---
+# Note: This is only actually used by the "Manage" subclass, but we are defining it here because
+# this class still has the duty of setting the nodeTypeName value in fetch_nodes, so it makes
+# more sense to declare in the same place.
+has '+node_types', default => sub {
+  my $self = shift;
+  
+  my $iconF = {
+    name  => 'iconcls',
+    xtype => 'ra-all-icon-assets-combo',
+    fieldLabel => 'Icon',
+  };
+  
+  my $urlF = {
+    name  => 'url', 
+    xtype => 'textfield',
+    fieldLabel => 'Link URL',
+    plugins => [{
+      ptype => 'fieldhelp',
+      text  => "Local internal URL path, starting with '/'"
+    }],
+    allowBlank => \0,
+    validator => jsfunc join(' ','function(v) {',
+      'return (v && v.search("/") == 0) ? true : false;',
+    '}')
+  };
+  
+  return [{
+    type     => 'folder',
+    title    => 'Folder',
+    iconCls  => 'ra-icon-folder',
+    addable  => 1,
+    editable => 1,
+    applyDialogOpts => {
+      height => 170,
+    },
+    fields => [{ %$iconF, value => 'x-tree-node-icon' }]
+  },
+  {
+    type     => 'search',
+    title    => 'Saved Search',
+    addable  => 0,
+    editable => 1,
+    applyDialogOpts => {
+      height => 170,
+    },
+    fields => [$iconF]
+  },
+  {
+    type     => 'link',
+    title    => 'Custom Link',
+    iconCls  => 'ra-icon-link-go',
+    addable  => 1,
+    editable => 1,
+    applyDialogOpts => {
+      height => 200,
+    },
+    fields => [{ %$iconF, value => 'ra-icon-link-go' },$urlF]
+  }]
+};  
+# ---
+
+
 has 'plugin_config', is => 'ro', lazy => 1, default => sub {
   my $self = shift;
   my $c = $self->app;
@@ -20,6 +83,9 @@ has 'plugin_config', is => 'ro', lazy => 1, default => sub {
   # (also requires Auth to be enabled)
   $config->{user_views} //= $c->can('_authcore_load_plugins') ? 1 : 0;
   
+  # User may supply additional custom tree node configs in an ArrayRef here:
+  $config->{custom_navtree_nodes} //= undef;
+  
   return $config;
 };
 
@@ -176,10 +242,14 @@ sub get_Node_config {
       $opts->{nodeTypeName} = 'link';
       $opts->{customAttrs}  = $attrs;
     }
+    else {
+      $opts->{nodeTypeName} = 'search';
+    }
     
 	}
 	# Navtree Node specific
 	else {
+    $opts->{nodeTypeName} = 'folder';
 		$opts->{allowCopy} = \0;
 	}
 	
@@ -273,6 +343,8 @@ sub TreeConfig {
 
 	push @items, $self->organize_navtree_node 
     if ($self->plugin_config->{allow_manage});
+    
+  push @items, $self->custom_navtree_nodes;
 
 	return \@items;
 }
@@ -319,8 +391,6 @@ sub saved_search_tree_items {
 
 
 
-
-
 sub organize_navtree_node {
 	my $self = shift;
 	return {
@@ -335,6 +405,32 @@ sub organize_navtree_node {
 	};
 }
 
+
+sub custom_navtree_nodes {
+  my $self = shift;
+  my $nodes = $self->plugin_config->{custom_navtree_nodes} or return ();
+  $nodes = [$nodes] unless ((ref($nodes)||'') eq 'ARRAY');
+  return map { $self->_prepare_custom_node_cfg($_) } @$nodes
+}
+
+sub _prepare_custom_node_cfg {
+  my $self = shift;
+  my $node = clone(shift);
+  
+  my $chlds = $node->{children} || [];
+  $chlds = [] unless ((ref($chlds)||'') eq 'ARRAY');
+  if(scalar(@$chlds) > 0) {
+    $node->{children} = [ map { $self->_prepare_custom_node_cfg($_) } @$chlds ];
+  }
+  else {
+    $node->{leaf} = 1;
+    $node->{expanded} = 1;
+  }
+  return $node
+}
+
+
+
 #sub deleted_objects_node {{
 #	id			=> 'deleted_objects',
 #	text		=> 'Deleted Objects',
